@@ -9,7 +9,7 @@
  * is constructed. This can be used to find subtle garbage collection problems.
  * Note that this is very time consuming... The first line below expresses that
  * no agressive checking is done, which is the default. */
-/* #define DO_AGGRESSIVE_GARBAGE_COLLECT   */
+// #define DO_AGGRESSIVE_GARBAGE_COLLECT
 
 #ifdef DO_AGGRESSIVE_GARBAGE_COLLECT
 #define AGGRESSIVE_GARBAGE_COLLECT_CHECK AT_collect()
@@ -21,25 +21,23 @@
 namespace aterm
 {
 
-static const size_t MAX_BLOCKS_PER_SIZE = 1024;
-
 static const size_t MAX_INLINE_ARITY = ((size_t)1 << ARITY_BITS)-(size_t)2;
-//#define MAX_INLINE_ARITY    ((1 << ARITY_BITS)-2)
+
 
 /* To change the block size, modify BLOCK_SHIFT only! */
 static const size_t BLOCK_SHIFT = 13;
 
 static const size_t BLOCK_SIZE = 1<<BLOCK_SHIFT;
-//#define BLOCK_SIZE       (1<<BLOCK_SHIFT)
+
 static const size_t BLOCK_TABLE_SIZE = 4099; /* nextprime(4096) */
-//#define BLOCK_TABLE_SIZE 4099     /* nextprime(4096) */
+
 
 template <typename T>
 inline HashNumber HN(const T i)
 {
   return (HashNumber)(i);
 }
-//#define HN(i)          ((HashNumber)(i))
+
 
 #ifdef AT_64BIT
 inline
@@ -47,9 +45,9 @@ size_t FOLD(const MachineWord w)
 {
   return HN(w)^(HN(w) >> 32);
 }
-//#define FOLD(w)         ((HN(w)) ^ (HN(w) >> 32))
+
 static const size_t PTR_ALIGN_SHIFT = 4;
-//#define PTR_ALIGN_SHIFT 4
+
 #endif // AT_64BIT
 
 #ifdef AT_32BIT
@@ -58,19 +56,15 @@ size_t FOLD(const MachineWord w)
 {
   return HN(w);
 }
-//#define FOLD(w)         (HN(w))
+
 static const size_t PTR_ALIGN_SHIFT = 2;
-//#define PTR_ALIGN_SHIFT 2
+
 #endif // AT_32BIT
 
 inline size_t ADDR_TO_BLOCK_IDX(const void* a)
 {
   return (((HashNumber)(a))>>(BLOCK_SHIFT+PTR_ALIGN_SHIFT)) % BLOCK_TABLE_SIZE;
 }
-/*
-#define ADDR_TO_BLOCK_IDX(a) \
-  ((((HashNumber)(a))>>(BLOCK_SHIFT+PTR_ALIGN_SHIFT)) % BLOCK_TABLE_SIZE)
-*/
 
 typedef struct Block
 {
@@ -78,7 +72,6 @@ typedef struct Block
   header_type data[BLOCK_SIZE];
 
   size_t size;
-  int frozen; /* this int is used as a boolean */
   struct Block* next_by_size;
   struct Block* next_before;
   struct Block* next_after;
@@ -92,20 +85,11 @@ typedef struct BlockBucket
   struct Block* first_after;
 } BlockBucket;
 
-static const size_t AT_BLOCK = 0;
-static const size_t AT_OLD_BLOCK = 1;
-//#define AT_BLOCK      0
-//#define AT_OLD_BLOCK  1
-
 typedef struct TermInfo
 {
-  Block*       at_blocks[2];
+  Block*       at_block;
   header_type* top_at_blocks;
-  size_t       at_nrblocks;
   ATerm        at_freelist;
-  size_t       nb_live_blocks_before_last_gc;
-  size_t       nb_reclaimed_blocks_during_last_gc;
-  size_t       nb_reclaimed_cells_during_last_gc;
 } TermInfo;
 
 extern TermInfo* terminfo;
@@ -117,36 +101,9 @@ inline size_t SIZE_TO_BYTES(const size_t size)
 {
   return size*sizeof(header_type);
 }
-//#define SIZE_TO_BYTES(size) ((size)*sizeof(header_type))
-
-inline
-void SET_FROZEN(Block* block)
-{
-  block->frozen=1;
-}
-//#define SET_FROZEN(block) ((block)->frozen=1)
-
-inline
-bool IS_FROZEN(const Block* block)
-{
-  return block->frozen==1;
-}
-//#define IS_FROZEN(block) ((block)->frozen==1)
-
-inline
-void CLEAR_FROZEN(Block* block)
-{
-  block->frozen=0;
-}
-//#define CLEAR_FROZEN(block) ((block)->frozen=0)
 
 extern BlockBucket block_table[BLOCK_TABLE_SIZE];
 
-extern size_t nb_minor_since_last_major;
-extern size_t old_bytes_in_young_blocks_after_last_major;
-extern size_t old_bytes_in_old_blocks_after_last_major;
-extern size_t old_bytes_in_young_blocks_since_last_major;
-
 extern size_t maxTermSize;
 
 extern header_type* min_heap_address;
@@ -157,9 +114,9 @@ bool AT_isPotentialTerm(const ATerm term)
 {
   return min_heap_address <= (header_type*)(term) && (header_type*)(term) <= max_heap_address;
 }
-//#define AT_isPotentialTerm(term) (min_heap_address <= (header_type*)(term) && (header_type*)(term) <= max_heap_address)
 
-void AT_initMemory(int argc, char** argv);
+
+void AT_initMemory();
 void AT_initMemmgnt();
 void AT_cleanupMemory();
 HashNumber AT_hashnumber(const ATerm t);
@@ -168,9 +125,6 @@ void  AT_freeTerm(const size_t size, const ATerm t);
 bool AT_isValidTerm(const ATerm term);
 ATerm AT_isInsideValidTerm(ATerm term);
 size_t AT_inAnyFreeList(const ATerm t);
-void AT_printAllTerms(FILE* file);
-void AT_printAllAFunCounts(FILE* file);
-size_t AT_getAllocatedCount();
 
 struct _ATprotected_block
 {
@@ -199,14 +153,12 @@ static const size_t INITIAL_TERM_TABLE_CLASS = 17;
 inline
 void CHECK_HEADER(const header_type h)
 {
-  assert(GET_AGE(h)==0 && !IS_MARKED(h));
+  assert(!IS_MARKED(h));
 }
 
 inline
-void CHECK_ARGUMENT(const ATermAppl t, const size_t n)
+void CHECK_ARGUMENT(const ATermAppl /*t*/, const size_t /*n*/)
 {
-  assert((GET_AGE(t->header) <= GET_AGE(ATgetArgument(t,n)->header)));
-  assert((GET_AGE(t->header) <= GET_AGE(at_lookup_table[ATgetAFun((ATermAppl)t)]->header)));
 }
 
 inline
@@ -218,7 +170,7 @@ void CHECK_ARITY(const size_t ari1, const size_t ari2)
 inline
 size_t START(const MachineWord w)
 {
-  return FOLD(HIDE_AGE_MARK(w));
+  return FOLD(w);
 }
 
 inline
@@ -242,9 +194,7 @@ void CHECK_TERM(const ATerm t)
 /*}}}  */
 
 extern ATerm* hashtable;
-// static size_t table_class = INITIAL_TERM_TABLE_CLASS;
-// static HashNumber table_size    = AT_TABLE_SIZE(INITIAL_TERM_TABLE_CLASS);
-static HashNumber table_mask    = AT_TABLE_MASK(INITIAL_TERM_TABLE_CLASS);
+extern HashNumber table_mask;
 
 /*{{{  ATermAppl ATmakeAppl(AFun sym, ...) */
 
