@@ -15,7 +15,6 @@
 #include <functional>
 #include "mcrl2/data/builder.h"
 #include "mcrl2/data/data_specification.h"
-#include "mcrl2/data/detail/normalize_sorts_fwd.h"
 
 namespace mcrl2
 {
@@ -111,7 +110,7 @@ struct normalize_sorts_function: public std::unary_function<data::sort_expressio
 template <typename T>
 void normalize_sorts(T& x,
                      const data::data_specification& data_spec,
-                     typename boost::disable_if<typename boost::is_base_of<atermpp::aterm_base, T>::type>::type* /* = 0 */
+                     typename boost::disable_if<typename boost::is_base_of<atermpp::aterm_base, T>::type>::type* = 0
                     )
 {
   core::make_update_apply_builder<data::sort_expression_builder>
@@ -121,7 +120,7 @@ void normalize_sorts(T& x,
 template <typename T>
 T normalize_sorts(const T& x,
                   const data::data_specification& data_spec,
-                  typename boost::enable_if<typename boost::is_base_of<atermpp::aterm_base, T>::type>::type* /* = 0 */
+                  typename boost::enable_if<typename boost::is_base_of<atermpp::aterm_base, T>::type>::type* = 0
                  )
 {
   return core::make_update_apply_builder<data::sort_expression_builder>
